# PT Sans Webfont Kit

Webfont kit for [PT Sans](http://www.paratype.com/public/).

PT Sans is based on Russian sans serif types of the second part of the XX century, but at the same time has a very distinctive features of modern humanistic design.
The family consists of 8 styles:

- 4 basic styles;
- 2 captions styles for small sizes
- 2 narrows styles for economic setting.

Installable via [Bower](http://bower.io):

    bower install pt-sans